summaryrefslogtreecommitdiffstats
path: root/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
diff options
context:
space:
mode:
Diffstat (limited to 'kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h')
-rw-r--r--kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h b/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
index 89a32571..6bc46ab1 100644
--- a/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
+++ b/kbabel/kbabeldict/modules/dbsearchengine2/KDBSearchEngine2.h
@@ -26,7 +26,7 @@ class KDBSearchEngine2 : public SearchEngine
public:
- KDBSearchEngine2(TQObject *tqparent=0, const char *name=0);
+ KDBSearchEngine2(TQObject *parent=0, const char *name=0);
virtual ~KDBSearchEngine2();
//init if needed.
@@ -78,9 +78,9 @@ class KDBSearchEngine2 : public SearchEngine
* search engine. The returned widget should not be bigger than
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
* @param tqparent the tqparent of the returned widget
*/
- virtual PrefWidget* preferencesWidget(TQWidget *tqparent);
+ virtual PrefWidget* preferencesWidget(TQWidget *parent);
/** @returns information about this SearchEngine */
virtual const KAboutData *about() const;
@@ -78,9 +78,9 @@ class KDBSearchEngine2 : public SearchEngine
* 400x400. If you need more space, you maybe want to use
* a tabbed widget.
- * @param tqparent the tqparent of the returned widget
+ * @param parent the parent of the returned widget
*/